@@ -1,10 +1,10 @@
 /*
     Melody maid
-    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,22 +13,13 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "mm_dialog.h"
 #include "mm_list.h"
 #include <gdk/gdkkeysyms.h>
 
 
-static void mm_dialog_class_init (MmDialogClass *klass);
-static void mm_dialog_init       (MmDialog      *dialog);
-static void mm_dialog_escape     (MmDialog      *dialog);
-
-
-static GtkDialogClass *parent_class = NULL;
-
-
 enum
 {
   ESCAPE_SIGNAL,
@@ -42,31 +33,8 @@ static gint mm_dialog_signals[LAST_SIGNAL] = {0};
 /******************************************************************************
 *                                                                             *
 ******************************************************************************/
-GtkType
-mm_dialog_get_type (void)
-{
-  static GType type = 0;
-
-  if (!type)
-    {
-      const static GTypeInfo info =
-      {
-        sizeof (MmDialogClass),
-        NULL,               /* base_init */
-        NULL,               /* base_finalize */
-        (GClassInitFunc)mm_dialog_class_init,
-        NULL,               /* class_finalize */
-        NULL,               /* class_data */
-        sizeof (MmDialog),
-        0,                  /* n_preallocs */
-        (GInstanceInitFunc)mm_dialog_init,
-      };
-
-      type = g_type_register_static (GTK_TYPE_DIALOG, "MmDialog", &info, 0);
-    }
-
-  return type;
-}
+G_DEFINE_TYPE (MmDialog, mm_dialog, GTK_TYPE_DIALOG);
+static void mm_dialog_escape (MmDialog *dialog);
 
 
 static void
@@ -74,8 +42,6 @@ mm_dialog_class_init (MmDialogClass *klass)
 {
   GtkBindingSet *binding_set;
 
-  parent_class = g_type_class_peek_parent (klass);
-
   klass->escape = mm_dialog_escape;
 
   mm_dialog_signals[ESCAPE_SIGNAL]
