@@ -1,10 +1,10 @@
 /*
     Melody maid
-    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "general.h"
 #include "mm_list.h"
@@ -22,11 +21,6 @@
 #include <gdk/gdkkeysyms.h>
 
 
-static void mm_list_class_init (MmListClass *klass);
-static void mm_list_init       (MmList      *list);
-static void mm_list_destroy    (GtkObject   *object);
-
-
 enum
 {
   CHANGED_SIGNAL,
@@ -44,38 +38,14 @@ enum
 };
 
 
-static GtkWindowClass *parent_class = NULL;
 static gint mm_list_signals[LAST_SIGNAL] = {0};
 
 
 /******************************************************************************
 *                                                                             *
 ******************************************************************************/
-GtkType
-mm_list_get_type (void)
-{
-  static GType type = 0;
-
-  if (!type)
-    {
-      const static GTypeInfo info =
-      {
-        sizeof (MmListClass),
-        NULL,               /* base_init */
-        NULL,               /* base_finalize */
-        (GClassInitFunc)mm_list_class_init,
-        NULL,               /* class_finalize */
-        NULL,               /* class_data */
-        sizeof (MmList),
-        0,                  /* n_preallocs */
-        (GInstanceInitFunc)mm_list_init,
-      };
-
-      type = g_type_register_static (GTK_TYPE_TREE_VIEW, "MmList", &info, 0);
-    }
-
-  return type;
-}
+G_DEFINE_TYPE (MmList, mm_list, GTK_TYPE_TREE_VIEW);
+static void mm_list_destroy (GtkObject *object);
 
 
 static void
@@ -83,9 +53,7 @@ mm_list_class_init (MmListClass *klass)
 {
   GtkObjectClass *object_class;
 
-  object_class = (GtkObjectClass *)klass;
-  parent_class = g_type_class_peek_parent (klass);
-
+  object_class = GTK_OBJECT_CLASS (klass);
   object_class->destroy = mm_list_destroy;
 
   klass->changed  = NULL;
@@ -164,7 +132,7 @@ mm_list_destroy (GtkObject *object)
       MM_LIST (object)->signal = FALSE;
       mm_list_delete_all (MM_LIST (object));
     }
-  GTK_OBJECT_CLASS (parent_class)->destroy (object);
+  GTK_OBJECT_CLASS (mm_list_parent_class)->destroy (object);
 }
 
 
