@@ -1,6 +1,6 @@
 /*
     Melody maid
-    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -71,8 +71,8 @@ process_dialog (void)
                                     G_CALLBACK (misc_dialog_key_press), NULL);
   g_object_set_data (G_OBJECT (dialog), "user_data", GINT_TO_POINTER (FALSE));
   /* ja:エントリー */
-  entry0 = gtk_entry_new_with_max_length (256);
-  entry1 = gtk_entry_new_with_max_length (256);
+  entry0 = gtk_entry_new ();
+  entry1 = gtk_entry_new ();
   if (cmd_play)
     gtk_entry_set_text (GTK_ENTRY (entry0), cmd_play);
   if (cmd_stop)
